Module fleets_api

Module fleets_api 

Enums

FleetCreateError
struct for typed errors of method fleet_create
FleetDeleteError
struct for typed errors of method fleet_delete
FleetGetError
struct for typed errors of method fleet_get
FleetLinkAppVersionError
struct for typed errors of method fleet_link_app_version
FleetPoliciesCreateError
struct for typed errors of method fleet_policies_create
FleetPoliciesDeleteError
struct for typed errors of method fleet_policies_delete
FleetPoliciesGetError
struct for typed errors of method fleet_policies_get
FleetPoliciesListError
struct for typed errors of method fleet_policies_list
FleetPoliciesUpdateError
struct for typed errors of method fleet_policies_update
FleetUnlinkAppVersionError
struct for typed errors of method fleet_unlink_app_version
FleetUpdateError
struct for typed errors of method fleet_update
FleetsError
struct for typed errors of method fleets

Functions

fleet_create
Create a fleet. A fleet is a top-level object; you must create child resources to work properly.
fleet_delete
Delete a fleet, its policies and links between the application versions.
fleet_get
Retrieve a fleet with its details.
fleet_link_app_version
Link an application version to a fleet. By linking this version, the fleet will automatically create deployments of this version according to the fleet policies.
fleet_policies_create
Create a fleet policy. Policies are conditions that the fleet must respect.
fleet_policies_delete
Delete a policy. It will not delete the fleet.
fleet_policies_get
Retrieve a specific policy of a fleet.
fleet_policies_list
List all the policies of a fleet.
fleet_policies_update
Update a policy with new specifications.
fleet_unlink_app_version
Unlink an application version from a fleet. It will not delete the application version or the fleet
fleet_update
Update a fleet with new specifications.
fleets
List all the fleets you own.