pub struct SessionGet {Show 15 fields
pub session_id: String,
pub custom_id: Option<String>,
pub status: String,
pub ready: bool,
pub linked: bool,
pub kind: String,
pub user_count: i32,
pub app_version: i32,
pub create_time: String,
pub elapsed: i32,
pub error: Option<String>,
pub session_users: Option<Vec<SessionUser>>,
pub session_ips: Option<Vec<SessionUser>>,
pub deployment: Option<Box<Deployment>>,
pub webhook_url: Option<String>,
}Fields
session_id: StringUnique UUID
custom_id: Option<String>Custom ID if Available
status: StringCurrent status of the session
ready: boolIf the session is linked to a ready deployment
linked: boolIf the session is linked to a deployment
kind: StringType of session created
user_count: i32Count of user this session currently have
app_version: i32App version linked to the session
create_time: StringSession created at
elapsed: i32Elapsed time
error: Option<String>Error Detail
session_users: Option<Vec<SessionUser>>Users in the session
session_ips: Option<Vec<SessionUser>>IPS in the session
deployment: Option<Box<Deployment>>webhook_url: Option<String>When your Session is Linked, Unprocessable or in Error, we will POST the session’s details on the webhook_url
Implementations