pub fn pull_profile_create(
configuration: &Configuration,
endpoint_name: &str,
payload: PullProfilePostPayload,
) -> Result<PullProfilePostResponse, Error<PullProfileCreateError>>Expand description
Create a pull profile. Pull profile will upload data from an endpoint storage to a deployment container on boot. You must link the application version to the pull profile first.