Enums
- Fleet
Create Error - struct for typed errors of method
fleet_create - Fleet
Delete Error - struct for typed errors of method
fleet_delete - Fleet
GetError - struct for typed errors of method
fleet_get - Fleet
Link AppVersion Error - struct for typed errors of method
fleet_link_app_version - Fleet
Policies Create Error - struct for typed errors of method
fleet_policies_create - Fleet
Policies Delete Error - struct for typed errors of method
fleet_policies_delete - Fleet
Policies GetError - struct for typed errors of method
fleet_policies_get - Fleet
Policies List Error - struct for typed errors of method
fleet_policies_list - Fleet
Policies Update Error - struct for typed errors of method
fleet_policies_update - Fleet
Unlink AppVersion Error - struct for typed errors of method
fleet_unlink_app_version - Fleet
Update Error - struct for typed errors of method
fleet_update - Fleets
Error - struct for typed errors of method
fleets
Functions
- fleet_
create - Create a fleet. A fleet is a top-level object; you must create child resources to work properly.
- fleet_
delete - Delete a fleet, its policies and links between the application versions.
- fleet_
get - Retrieve a fleet with its details.
- fleet_
link_ app_ version - Link an application version to a fleet. By linking this version, the fleet will automatically create deployments of this version according to the fleet policies.
- fleet_
policies_ create - Create a fleet policy. Policies are conditions that the fleet must respect.
- fleet_
policies_ delete - Delete a policy. It will not delete the fleet.
- fleet_
policies_ get - Retrieve a specific policy of a fleet.
- fleet_
policies_ list - List all the policies of a fleet.
- fleet_
policies_ update - Update a policy with new specifications.
- fleet_
unlink_ app_ version - Unlink an application version from a fleet. It will not delete the application version or the fleet
- fleet_
update - Update a fleet with new specifications.
- fleets
- List all the fleets you own.