pub struct AppVersionCreateSessionConfig {
pub kind: Kind,
pub sockets: i32,
pub autodeploy: Option<bool>,
pub empty_ttl: Option<i32>,
pub session_max_duration: Option<i32>,
}Fields
kind: KindThe kind of session to create. If ‘Default’ if chosen, the ‘session_config’ will be ignored. The kind of session must be: Default, Seat, Match
sockets: i32The number of game slots on each deployment of this app version.
autodeploy: Option<bool>If a deployment should be made autonomously if there is not enough sockets open on a new session.
empty_ttl: Option<i32>The number of minutes a deployment of this app version can spend with no session connected before being terminated.
session_max_duration: Option<i32>The number of minutes after a session-type deployment has been terminated to remove all the session information connected to your deployment. Minimum and default value is set to 60 minutes so you can manage your session termination before it is removed.
Implementations
Sourceimpl AppVersionCreateSessionConfig
impl AppVersionCreateSessionConfig
pub fn new(kind: Kind, sockets: i32) -> AppVersionCreateSessionConfig